@class NSExtendedBox, AbbreviatingTextField, ChatInputLine, PeopleList, ChatDOMView, ChooseBuddyButton;
@class ExtendedTextField, ChatFieldEditor, ChatNotifier, CertViewer, ExtendedSplitViewGrabber, MyNameControl;
@class AnimatingTabView, LinkSheetController, Chat, SecureWindow;

@interface AbstractRichTextGenerator : NSObject
{
    NSAttributedString *_text;
    NSColor *_fgColor;
    NSColor *_bgColor;
    NSFont *_baseFont;
    NSMutableArray *_tagStack;
    NSMutableArray *_tagValueStack;
    NSMutableString *_out;
}

+ (id)richTextFromAttributedString:(id)fp8 baseFont:(id)fp12 defaultBGColor:(id)fp16;
+ (id)plainTextFromAttributedString:(id)fp8;
+ (id)hrefTextForURL:(id)fp8;
+ (id)_bgColorForHTML:(id)fp8;
+ (id)parseHTML:(id)fp8 resultingBGColor:(id *)fp12 resultingFontColor:(id *)fp16 defaultFont:(id)fp20;
+ (id)_generatorString;
- (id)initWithAttributedString:(id)fp8;
- (void)dealloc;
- (void)setDefaultForegroundColor:(id)fp8;
- (void)setDefaultBackgroundColor:(id)fp8;
- (void)setBaseFont:(id)fp8;
- (id)_valueOfTag:(id)fp8;
- (void)_appendTagAttributeWithAttribute:(id)fp8 value:(id)fp12;
- (void)_pushPopSingletonTag:(id)fp8 attributesAndValues:(id)fp12;
- (void)_pushTag:(id)fp8 tagValue:(id)fp12 attributesAndValues:(id)fp16;
- (void)_pushTag:(id)fp8 tagValue:(id)fp12 attribute:(id)fp16 value:(id)fp20;
- (void)_popTag;
- (void)_popAllTags;
- (void)_popTag:(id)fp8 ifValueNot:(id)fp12;
- (void)_generateImageTagWithTextAttachment:(id)fp8 fileName:(id)fp12 ID:(id)fp16 width:(id)fp20 height:(id)fp24 fileSize:(id)fp28;
- (void)_generateHTMLForString:(id)fp8 attributes:(id)fp12;
- (id)generateRichText;
- (id)generatePlainText;
- (id)_currentColor;
- (id)_currentFont;
- (BOOL)_isXHTML;
- (id)_brTag;
- (void)_pushHTMLTag;
- (void)_pushBodyTagWithForegroundColor:(id)fp8 backgroundColor:(id)fp12 isRTL:(BOOL)fp16;
- (void)_generateTagsWithBold:(id)fp8 italic:(id)fp12 link:(id)fp16 font:(id)fp20 color:(id)fp24 bgColor:(id)fp28 underline:(id)fp32 myName:(id)fp36;

@end

@interface AIMLGenerator : AbstractRichTextGenerator
{
}

+ (id)parseHTML:(id)fp8 resultingBGColor:(id *)fp12 resultingFontColor:(id *)fp16 defaultFont:(id)fp20;
+ (id)_generatorString;
+ (id)_bgColorForHTML:(id)fp8;
- (void)_pushHTMLTag;
- (void)_pushBodyTagWithForegroundColor:(id)fp8 backgroundColor:(id)fp12 isRTL:(BOOL)fp16;
- (id)_currentColor;
- (id)_currentBgColor;
- (id)_currentFont;
- (void)_generateTagsWithBold:(id)fp8 italic:(id)fp12 link:(id)fp16 font:(id)fp20 color:(id)fp24 bgColor:(id)fp28 underline:(id)fp32 myName:(id)fp36;
- (id)_brTag;
- (BOOL)_isXHTML;
- (void)_appendTagAttributeWithAttribute:(id)fp8 value:(id)fp12;

@end

@protocol PeopleListDelegate
- (id)peopleList:(id)fp8 alternateStatusTextForPresentity:(id)fp12;
- (id)peopleList:(id)fp8 alternateNameTextForPresentity:(id)fp12;
- (float)peopleList:(id)fp8 alphaForStatus:(unsigned int)fp12;
- (id)peopleList:(id)fp8 addablePeople:(id)fp12;
- (BOOL)peopleList:(id)fp8 canRemoveRows:(id)fp12;
- (void)peopleList:(id)fp8 deleteGroup:(id)fp12;
- (id)peopleList:(id)fp8 filterPresentityFromPasteboard:(id)fp12;
- (void)peopleList:(id)fp8 setGroupsSortOrder:(id)fp12;
- (BOOL)peopleList:(id)fp8 addPersonWithoutID:(id)fp12;
- (id)peopleList:(id)fp8 siblingsForPresentity:(id)fp12;
- (BOOL)peopleList:(id)fp8 people:(id)fp12 draggedFromGroups:(id)fp16 toGroup:(id)fp20 atLocation:(int)fp24 copying:(BOOL)fp28;
- (BOOL)peopleList:(id)fp8 pastePeople:(id)fp12 intoGroup:(id)fp16;
- (BOOL)peopleList:(id)fp8 deletePeople:(id)fp12;
- (id)peopleList:(id)fp8 menuForGroup:(id)fp12;
- (void)peopleListSelectedItemInfoChanged:(id)fp8;
- (id)propertiesForGroup:(id)fp8;
@end

@interface ChatController : NSObject <PeopleListDelegate>
{
    struct _NSRect _savedRect;
    BOOL _inTransition;
    BOOL _pendingShowParticipants;
    BOOL _windowClosing;
    NSImageView *_serviceImage;
    NSExtendedBox *_statusArea;
    NSExtendedBox *_toFromDivider;
    ExtendedSplitViewGrabber *_inputLineGrabber;
    ExtendedSplitViewGrabber *_rejoinGrabber;
    ExtendedSplitViewGrabber *_emptyGrabber;
    NSTextField *_participantCount;
    NSView *_fromStatusArea;
    NSView *_toStatusArea;
    AbbreviatingTextField *_fromText;
    AbbreviatingTextField *_toText;
    MyNameControl *_fromPopup;
    MyNameControl *_toPopup;
    NSView *_enclosingView;
    ChatInputLine *_inputLine;
    AbbreviatingTextField *_whyIsInputLineGoneField;
    AnimatingTabView *_inputLineTabView;
    NSView *_participantsArea;
    PeopleList *_peopleList;
    NSDrawer *_peopleDrawer;
    ChatDOMView *_transcript;
    id _transcriptIB;
    NSMenu *_chatContextMenu;
    ChooseBuddyButton *_chooseIDButton;
    NSView *_transcriptArea;
    float _initialMinWidth;
    NSPanel *_linkSheet;
    ExtendedTextField *_linkTextField;
    LinkSheetController *_linkSheetController;
    NSWindow *_inviteMsgSheet;
    NSTextField *_inviteMsgText;
    NSTextField *_inviteMsgLabel;
    NSString *_inviteMsg;
    BOOL _participantsWereVisible;
    NSView *_buttonArea;
    NSButton *_notifyAccept;
    NSButton *_joinAtLogin;
    NSButton *_notifyReject;
    NSButton *_notifyBlock;
    float _buttonAmountVisible;
    NSString *_origNotifyAcceptTitle;
    NSTabView *_notifyButtonTabView;
    NSButton *_rejoinChatButton;
    NSProgressIndicator *_joiningSpinner;
    NSWindow *_chooseIDSheet;
    NSWindow *_chatOptionsSheet;
    NSPopUpButton *_chatOptionsStyle;
    ExtendedTextField *_chatOptionsName;
    NSViewAnimation *_statusViewAnimation;
    ChatFieldEditor *_fieldEditor;
    Chat *_chat;
    BOOL _primaryController;
    BOOL _chooseIDMenuIsValid;
    BOOL _isDeciding;
    BOOL _msgsHidden;
    BOOL _finishChatWhenClosed;
    BOOL _inputLineSpacerRemoved;
    ChatNotifier *_notifier;
    SecureWindow *_window;
    BOOL _resizingInputLine;
    float _inputLineRightMargin;
    CertViewer *_certViewer;
    BOOL _isInTab;
    BOOL _isResizing;
}

+ (id)chatControllerInstalledInView:(id)fp8;
- (void)chatWillBecomeVisibleInWindow:(id)fp8 resizeWindow:(BOOL)fp12;
- (void)chatWillBeRemovedFromWindow:(id)fp8;
- (BOOL)animationShouldStart:(id)fp8;
- (void)animationDidStop:(id)fp8;
- (void)animationDidEnd:(id)fp8;
- (void)animation:(id)fp8 didReachProgressMark:(float)fp12;
- (BOOL)_isStatusAreaVisible;
- (void)_makeStatusAreaShowFrom:(BOOL)fp8 to:(BOOL)fp12;
- (id)_possibleFromAccounts;
- (id)_possibleToParticipants;
- (id)menuForMyRolloverButton:(id)fp8;
- (void)_prepareStatusArea;
- (void)_synchonizeStatusAreaItems;
- (void)_switchToPresentityFromMenuItem:(id)fp8;
- (void)_switchFromAccountFromMenuItem:(id)fp8;
- (void)_hideStatusArea;
- (void)_showStatusArea;
- (BOOL)_statusAreaWantsToBeVisible;
- (void)_updateStatusArea;
- (void)awakeFromNib;
- (void)setResizersVisible:(BOOL)fp8;
- (void)unhookResizers;
- (void)hookupResizersToSplitView:(id)fp8;
- (void)_finishChat;
- (void)dealloc;
- (void)_windowDidResize:(id)fp8;
- (void)handleChatWindowClosing:(id)fp8;
- (id)window;
- (id)selectedPresentities;
- (BOOL)isComposing;
- (id)account;
- (id)peopleList;
- (id)chat;
- (float)minWidth;
- (void)_loadRejoinButton;
- (void)setChat:(id)fp8;
- (void)setChatRoomName:(id)fp8;
- (BOOL)finishesChatWhenClosed;
- (void)setFinishesChatWhenClosed:(BOOL)fp8;
- (id)inputLine;
- (id)fieldEditor;
- (void)_updateInputLineAttachmentSupport;
- (BOOL)inputLineHasFocus;
- (void)setPrimaryChatController:(BOOL)fp8;
- (id)_activeChatChat;
- (BOOL)_serviceMightChat;
- (BOOL)_anonymousPeopleInPeopleList;
- (id)displayName:(BOOL)fp8;
- (void)_postDisplayNameChanged;
- (void)_postPeopleChanged;
- (int)joinState;
- (int)style;
- (id)people;
- (id)notifier;
- (BOOL)isActive;
- (BOOL)isInTab;
- (void)setIsInTab:(BOOL)fp8;
- (void)_fixBottomBorderThickness;
- (void)_clearCurrentPosition;
- (void)_saveCurrentPosition;
- (struct _NSRect)_rectAdjustingForSavedPositionWithRect:(struct _NSRect)fp8;
- (BOOL)isResizing;
- (void)_adjustInputLineHeightBy:(float)fp8 resizeWindow:(BOOL)fp12;
- (void)_setInputLineHeight:(float)fp8 resizeWindow:(BOOL)fp12;
- (void)_showInputLine:(BOOL)fp8;
- (void)_msgStyleChanged:(id)fp8;
- (float)_currentTextHeight;
- (void)controlTextDidChange:(id)fp8;
- (void)_inputLineDidEndLiveResize:(id)fp8;
- (BOOL)resizingInputLine;
- (BOOL)inputLineCanAttachFile;
- (id)enclosingView;
- (id)transcriptView;
- (id)_preparedFieldEditor;
- (void)makeInputLineKey;
- (void)insertText:(id)fp8;
- (void)paste:(id)fp8;
- (void)pasteAndMatchStyle:(id)fp8;
- (void)tabView:(id)fp8 willSwitchFromTab:(int)fp12 toTab:(int)fp16 effect:(int *)fp20 direction:(int *)fp24;
- (BOOL)isInputLineVisible;
- (void)_setUnjoinedState;
- (void)_setJoiningState;
- (void)_setJoinedState;
- (void)makeInputLineFlushLeft:(BOOL)fp8;
- (void)_accountLoginStatusChanged:(id)fp8;
- (void)_updateInputLineTabView:(id)fp8;
- (BOOL)canParticipantsBeVisible;
- (BOOL)_wereParticipantsVisible;
- (BOOL)areParticipantsVisible;
- (void)showParticipants:(id)fp8;
- (void)hideParticipants:(id)fp8;
- (void)toggleParticipants:(id)fp8;
- (void)personDoubleClicked:(id)fp8;
- (void)drawerDidOpen:(id)fp8;
- (void)drawerWillClose:(id)fp8;
- (void)toggleHidePictures:(id)fp8;
- (void)toggleHideAudioStatus:(id)fp8;
- (void)toggleHideVideoStatus:(id)fp8;
- (void)sortByStatus:(id)fp8;
- (void)sortByFirstName:(id)fp8;
- (void)sortByLastName:(id)fp8;
- (void)_updateAddBuddyButtonState;
- (BOOL)addNewPresentities:(id)fp8;
- (void)addLink:(id)fp8;
- (void)acceptLinkText:(id)fp8;
- (void)cancelLinkSheet:(id)fp8;
- (void)removeLinkSheet:(id)fp8;
- (void)_linkSheetDidEnd:(id)fp8 returnCode:(int)fp12 contextInfo:(void *)fp16;
- (BOOL)textView:(id)fp8 clickedOnLink:(id)fp12 atIndex:(unsigned int)fp16;
- (id)_messageTextAndFlags:(int *)fp8;
- (BOOL)_sendMessage:(BOOL)fp8 forceEmpty:(BOOL)fp12 forceSend:(BOOL)fp16;
- (void)_clearInputLine;
- (void)joinAtLoginChanged:(id)fp8;
- (void)rejoinChat:(id)fp8;
- (void)cancelMessage:(id)fp8;
- (void)_sendMessage;
- (void)sendMessage:(id)fp8;
- (void)sendPartialMessage:(id)fp8;
- (BOOL)canSendPartialMessage;
- (BOOL)textField:(id)fp8 didChangeSignificantly:(int)fp12;
- (BOOL)control:(id)fp8 textShouldBeginEditing:(id)fp12;
- (void)sendSMS:(id)fp8;
- (void)composeEMail:(id)fp8;
- (void)sendFile:(id)fp8;
- (void)insertSmiley:(id)fp8;
- (void)setRendererFromMenuItem:(id)fp8;
- (void)inviteToARDAsClient:(id)fp8;
- (void)inviteToARDAsServer:(id)fp8;
- (void)inviteToAudioChat:(id)fp8;
- (void)inviteToVideoChat:(id)fp8;
- (BOOL)canUseInputField;
- (void)_reformatOutgoingColors;
- (void)_reformatOutgoingFonts;
- (void)_reformatOverrideIncoming;
- (void)_reformatOverrideIncomingFont;
- (void)_reformatOverrideIncomingColors;
- (void)_watchMessageAddressingChanged;
- (void)toggleRecipientBar:(id)fp8;
- (BOOL)validateMenuItem:(id)fp8;
- (void)makeTextBigger:(id)fp8;
- (void)makeTextStandardSize:(id)fp8;
- (void)makeTextSmaller:(id)fp8;
- (void)_updateParticipantCount;
- (void)_chatOverallStatusChangedNotification:(id)fp8;
- (void)_memberChanged:(id)fp8;
- (void)finishChat:(id)fp8;
- (void)ignore:(id)fp8;
- (void)toggleQuietMode:(id)fp8;
- (void)showInAddressBook:(id)fp8;
- (void)block:(id)fp8;
- (void)_chatStatusChanged:(id)fp8;
- (void)_chatComposingStatusChanged:(id)fp8;
- (void)_chatErrorPosted:(id)fp8;
- (void)_showErrorSheet:(id)fp8;
- (void)_personInfoChanged:(id)fp8;
- (void)buddySelected:(id)fp8;
- (id)chooseBuddyButton:(id)fp8 filterPresentities:(id)fp12;
- (void)chooseBuddySheetCanceled:(id)fp8;
- (id)peopleList:(id)fp8 alternateNameTextForPresentity:(id)fp12;
- (id)peopleList:(id)fp8 alternateStatusTextForPresentity:(id)fp12;
- (float)peopleList:(id)fp8 alphaForStatus:(unsigned int)fp12;
- (id)propertiesForGroup:(id)fp8;
- (id)peopleList:(id)fp8 siblingsForPresentity:(id)fp12;
- (BOOL)canAddPeople;
- (id)peopleList:(id)fp8 addablePeople:(id)fp12;
- (void)peopleList:(id)fp8 setGroupsSortOrder:(id)fp12;
- (BOOL)peopleList:(id)fp8 canRemoveRows:(id)fp12;
- (void)peopleList:(id)fp8 deleteGroup:(id)fp12;
- (BOOL)peopleList:(id)fp8 deletePeople:(id)fp12;
- (void)_syncPeopleWithChat;
- (void)_adjustChatStyleAndLockUI:(BOOL)fp8;
- (void)chatWindowRevealed:(BOOL)fp8;
- (BOOL)peopleList:(id)fp8 pastePeople:(id)fp12 intoGroup:(id)fp16;
- (void)_peopleChanged;
- (BOOL)peopleListAboutToResort:(id)fp8;
- (id)peopleList:(id)fp8 filterPresentityFromPasteboard:(id)fp12;
- (BOOL)peopleList:(id)fp8 addPersonWithoutID:(id)fp12;
- (BOOL)peopleList:(id)fp8 people:(id)fp12 draggedFromGroups:(id)fp16 toGroup:(id)fp20 atLocation:(int)fp24 copying:(BOOL)fp28;
- (id)peopleList:(id)fp8 menuForGroup:(id)fp12;
- (void)peopleListSelectedItemInfoChanged:(id)fp8;
- (id)peopleListService:(id)fp8;
- (id)secureWindowCertificates:(id)fp8;
- (id)secureWindowTrustPolicies:(id)fp8;
- (void)_updateChatTranscriptSecurityState:(int)fp8 oldLevel:(int)fp12;
- (void)_chatSecurityLevelChanged:(id)fp8;
- (void)_syncLockState;
- (void)_hideLockMessage:(id)fp8;
- (void)_showLockMessage:(id)fp8;
- (void)_updateLockUIFromPreviousLevel:(int)fp8;
- (void)_requestCertificates;
- (void)_accountCapabilitiesChanged:(id)fp8;
- (void)_certificatesChanged:(id)fp8;
- (void)_chatStyleChanged:(id)fp8;
- (BOOL)isInTransition;
- (void)setInTransition:(BOOL)fp8;
- (void)setIsDeciding:(BOOL)fp8 doKnockKnock:(BOOL)fp12 withChatNotifier:(id)fp16;
- (void)forgetNotifier:(id)fp8;
- (BOOL)isDeciding;
- (void)setVisiblePortionOfNotifyButtons:(float)fp8 showInputLine:(BOOL)fp12;
- (void)acceptNotification:(id)fp8;
- (void)rejectNotification:(id)fp8;
- (void)blockNotification:(id)fp8;
- (void)_runInviteSheetForInvitees:(id)fp8;
- (void)acceptInviteMessage:(id)fp8;
- (void)cancelInviteMessage:(id)fp8;
- (void)_inviteMsgDidEnd:(id)fp8 returnCode:(int)fp12 contextInfo:(void *)fp16;
- (void)scrollToBottom:(id)fp8;
- (void)clearTranscript:(id)fp8;
- (void)showFindPanel:(id)fp8;
- (void)findNext:(id)fp8;
- (void)findPrevious:(id)fp8;
- (void)copySelectionToFindPboard:(id)fp8;
- (void)toggleHideSmileys:(id)fp8;
- (void)chooseBackgroundImage:(id)fp8;
- (void)clearBackground:(id)fp8;
- (void)toggleShowPictures:(id)fp8;
- (void)toggleShowNames:(id)fp8;
- (void)setChatShowsNames:(id)fp8;
- (void)setChatShowsPictures:(id)fp8;
- (void)setChatShowsNamesAndPictures:(id)fp8;
- (void)_updateChatModeSheet;
- (void)chooseChatOptions:(id)fp8;
- (void)pickChatMode:(id)fp8;
- (void)acceptChatOptions:(id)fp8;
- (void)cancelChatOptions:(id)fp8;
- (void)_chatOptionsDidEnd:(id)fp8 returnCode:(int)fp12 contextInfo:(void *)fp16;
- (void)_savePanelDidEnd:(id)fp8 returnCode:(int)fp12 contextInfo:(void *)fp16;
- (void)saveChatAs:(id)fp8;

@end